#define TP_BYTE         1
#define TP_WORD         2
#define TP_LONG         4

#define TRUE            1
#define FALSE           0

#define B8(y)  ( ((0x##y##L & 0x00000001L) >> 0) \
               | ((0x##y##L & 0x00000010L) >> 3) \
               | ((0x##y##L & 0x00000100L) >> 6) \
               | ((0x##y##L & 0x00001000L) >> 9) \
               | ((0x##y##L & 0x00010000L) >> 12) \
               | ((0x##y##L & 0x00100000L) >> 15) \
               | ((0x##y##L & 0x01000000L) >> 18) \
               | ((0x##y##L & 0x10000000L) >> 21) )


#define ATHLONPM_USAGE	0x00
#define ATHLONPM_ON	B8(00000001)
#define ATHLONPM_OFF	B8(00000010)
#define ATHLONPM_STAT	B8(00000100)
#define ATHLONPM_LIST	B8(00001000)
#define ATHLONPM_FIXUP  B8(00010000)

#define BYTE_t u8 // uint8_t
#define WORD_t u16 //uint16_t
#define LONG_t u32 //uint32_t

struct device
{
  struct device	*next;
  struct pci_dev *dev;
  unsigned int	config_cnt;
  int8_t	config[256];
};
/* End Of File	**************************************************************/
